<?php

namespace Drupal\commerce_klaviyo;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\commerce_klaviyo\Util\KlaviyoRequestPropertiesInterface;

/**
 * The base class for Klaviyo properties.
 *
 * @package Drupal\commerce_klaviyo
 */
abstract class KlaviyoPropertiesBase implements KlaviyoRequestPropertiesInterface {

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The array of properties to send to Klaviyo.
   *
   * @var array
   */
  protected $properties = [];

  /**
   * The source entity.
   *
   * @var \Drupal\Core\Entity\EntityInterface
   */
  protected $sourceEntity;

  /**
   * Constructs the ProductProperties.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityInterface $source_entity
   *   The source entity.
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityInterface $source_entity) {
    $this->configFactory = $config_factory;
    $this->sourceEntity = $source_entity;
  }

  /**
   * Sets a property.
   *
   * @param string $name
   *   The property name.
   * @param mixed $value
   *   The property value.
   */
  public function setProperty($name, $value) {
    $this->properties[$name] = $value;
  }

  /**
   * {@inheritdoc}
   */
  public function getProperties() {
    return $this->properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getSourceEntity() {
    return $this->sourceEntity;
  }

  /**
   * {@inheritdoc}
   */
  public function setSourceEntity(EntityInterface $source_entity) {
    $this->sourceEntity = $source_entity;
    return $this;
  }

}
